import itertools

import pandas as pd
from tqdm import tqdm

import fieldmaster
from fieldmaster.models.prophet_mv import PROPHETMV
from fieldmaster.models.prophet_uv import PROPHETUV
from fieldmaster.models.SARIMA import SARIMA
from fieldmaster.utils import load_data, sample_df


def evaluate_models(path: str) -> pd.DataFrame:

    models = [model for model in dir(fieldmaster.models) if "__" not in model]  # type: ignore
    intervals = [180, 90, 30, 15, 5, 3]

    df = load_data(path)

    results = pd.DataFrame(columns=["model", "interval", "RMSE", "MAE", "MAPE"])

    for setting in tqdm(list(itertools.product(models, intervals)) * 30):

        Xy, holdout = sample_df(df, setting[1])

        if setting[0] == "SARIMA":
            model = SARIMA(order=(0, 1, 1), seasonal_order=(1, 1, 1, 24)).fit(Xy, holdout)
        elif setting[0] == "prophet_uv":
            model = PROPHETUV().fit(Xy, holdout)
        elif setting[0] == "prophet_mv":
            model = PROPHETMV().fit(Xy, holdout)

        results.loc[len(results)] = [
            setting[0],
            setting[1],
            model.metrics_["RMSE"],
            model.metrics_["MAE"],
            model.metrics_["MAPE"],
        ]

    return results
