import numpy as np


def RMSE(y_true: np.ndarray, y_pred: np.ndarray) -> float:
    """
    Root mean squared error
    """
    return np.sqrt(np.mean((y_true - y_pred) ** 2))


def MAE(y_true: np.ndarray, y_pred: np.ndarray) -> float:
    """
    Mean absolute error
    """
    return np.mean(np.abs(y_true - y_pred))


def RSQ(y_true: np.ndarray, y_pred: np.ndarray) -> float:
    """
    R-squared
    """
    return 1 - np.sum((y_true - y_pred) ** 2) / np.sum((y_true - np.mean(y_true)) ** 2)


def MAPE(y_true: np.ndarray, y_pred: np.ndarray) -> float:
    """
    Mean absolute percentage error
    """
    return np.mean(np.abs((y_true - y_pred) / y_true)) * 100


def SMAPE(y_true: np.ndarray, y_pred: np.ndarray) -> float:
    """
    Symmetric mean absolute percentage error
    """
    return np.mean(2 * np.abs(y_true - y_pred) / (np.abs(y_true) + np.abs(y_pred))) * 100
