from __future__ import annotations

import pandas as pd
from fbprophet import Prophet

from fieldmaster.models.SARIMA import SARIMA


class PROPHETUV(SARIMA):
    """
    Univariate Prophet model
    """

    def __init__(
        self,
        n_days_forecast: int = 1,
        confidence_level: float = 0.90,
    ) -> None:
        """
        Initialize the Prophet model
        """

        self.n_days_forecast = n_days_forecast
        self.confidence_level = confidence_level

    def fit(self, Xy_train: pd.DataFrame, holdout: pd.DataFrame) -> PROPHETUV:
        """
        Fit the SARIMA model
        """

        # Fit the SARIMA model
        self.model = self._get_fiited_model(Xy_train)

        # Get the prediction for the number of days required
        forecast = self.model.predict(holdout)

        # Get the yhat and yhat_lower and yhat_upper
        self.yhat_ = forecast.yhat
        self.confidence_ = forecast[["yhat_upper", "yhat_lower"]]

        self.metrics_ = self._calculate_all_metrics(holdout.y.values)

        return self

    def _get_fiited_model(self, Xy_train: pd.DataFrame) -> Prophet:
        """
        Returns the Prophet model
        """

        return Prophet(
            daily_seasonality=True,
            interval_width=self.confidence_level,
        ).fit(Xy_train)
